@@ -2,6 +2,8 @@ import argparse
 import sys
 import traceback
 
+from docker import DockerClient
+
 from duckietown_build_utils import docker_push_optimized, DockerCompleteImageName, DockerCredentials
 from . import logger
 
@@ -12,7 +14,7 @@ def dt_push_main(args=None, credentials: DockerCredentials = None):
     parser = argparse.ArgumentParser()
     # parser.add_argument("--image", required=True)
     parsed, rest = parser.parse_known_args(args=args)
-
+    client = DockerClient.from_env()
     # noinspection PyBroadException
     try:
         if len(rest) != 1:
@@ -20,7 +22,7 @@ def dt_push_main(args=None, credentials: DockerCredentials = None):
 
         image = DockerCompleteImageName(rest[0])
         logger.info(f"pushing image {image}")
-        docker_push_optimized(image, credentials=credentials)
+        docker_push_optimized(client, image, credentials=credentials)
     except SystemExit:
         raise
     except BaseException:
